@@ -1,4 +1,5 @@
 #Class for connector objects. Currently (relatively) a placeholder; will need to be fleshed out more
 #Once oAuth authentication and logins are live.
 wiki_conClass <- setRefClass("wiki_conClass",
-                             fields = list("URL" = "character"))
\ No newline at end of file
+                             fields = list("URL" = "character",
+                                           "CurlOpts" = "list"))
\ No newline at end of file
